@@ -22,11 +22,11 @@ has data    => ();
 
 =head1 AUTHORS
 
-OHPA Software <http://ohpasw.com>
+Bizowie <http://bizowie.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 OHPA Software.
+Copyright (C) 2013 Bizowie
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
